==> ckb_sdk-0.17.0.tar.gz: test/type/script_test.dart <==
import 'package:ckb_sdk/ckb_sdk.dart';
import 'package:ckb_sdk/ckb_types.dart' show Script;
import 'package:test/test.dart';

void main() {
  final String ZERO_HASH = "0000000000000000000000000000000000000000000000000000000000000000";

  test('empty script type hash', () {
    Script script = Script(ZERO_HASH, []);
    expect("0xc371c8d6a0aed6018e91202d047c35055cfb0228e6709f1cd1d5f756525628b9", script.scriptHash);
  });

  test('script type hash', () {
    Script script = Script(ZERO_HASH, ["0x01"]);
    expect("0xcd5b0c29b8f5528d3a75e3918576db4d962a1d4b315dff7d3c50818cc373b3f5", script.scriptHash);
  });

  test('script type hash with code hash', () {
    String codeHash = blake2bHexString(
        "0x1400000000000e00100000000c000800000004000e0000000c00000014000000740100000000000000000600080004000600000004000000580100007f454c460201010000000000000000000200f3000100000078000100000000004000000000000000980000000000000005000000400038000100400003000200010000000500000000000000000000000000010000000000000001000000000082000000000000008200000000000000001000000000000001459308d00573000000002e7368737472746162002e74657874000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000b000000010000000600000000000000780001000000000078000000000000000a000000000000000000000000000000020000000000000000000000000000000100000003000000000000000000000000000000000000008200000000000000110000000000000000000000000000000100000000000000000000000000000000000000");
    Script script = Script(codeHash, []);
    expect('0xc00073200d2b2f4ad816a8d04bb2431ce0d3ebd49141b086eda4ab4e06bc3a21', script.scriptHash);
  });
}

==> ckb_sdk-0.23.0.tar.gz: test/type/script_test.dart <==
@Skip()

import 'package:ckb_sdk/ckb_sdk.dart';
import 'package:ckb_sdk/ckb_types.dart' show Script;
import 'package:test/test.dart';

void main() {
  final String ZERO_HASH =
      "0000000000000000000000000000000000000000000000000000000000000000";

  test('empty script type hash', () {
    Script script = Script(ZERO_HASH, '');
    expect("0xc371c8d6a0aed6018e91202d047c35055cfb0228e6709f1cd1d5f756525628b9",
        script.scriptHash);
  });

  test('script type hash', () {
    Script script = Script(ZERO_HASH, "0x01");
    expect("0xcd5b0c29b8f5528d3a75e3918576db4d962a1d4b315dff7d3c50818cc373b3f5",
        script.scriptHash);
  });

  test('script type hash with code hash', () {
    String codeHash = blake2bHexString(
        "0x1400000000000e00100000000c000800000004000e0000000c00000014000000740100000000000000000600080004000600000004000000580100007f454c460201010000000000000000000200f3000100000078000100000000004000000000000000980000000000000005000000400038000100400003000200010000000500000000000000000000000000010000000000000001000000000082000000000000008200000000000000001000000000000001459308d00573000000002e7368737472746162002e74657874000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000b000000010000000600000000000000780001000000000078000000000000000a000000000000000000000000000000020000000000000000000000000000000100000003000000000000000000000000000000000000008200000000000000110000000000000000000000000000000100000000000000000000000000000000000000");
    Script script = Script(codeHash, '');
    expect('0xc00073200d2b2f4ad816a8d04bb2431ce0d3ebd49141b086eda4ab4e06bc3a21',
        script.scriptHash);
  });
}
